==> sdk-3.3.2-sources.jar: com/kontakt/sdk/android/ble/device/SecureProfile.java <==
package com.kontakt.sdk.android.ble.device;

import android.os.Parcel;
import com.kontakt.sdk.android.ble.spec.KontaktTelemetry;
import com.kontakt.sdk.android.common.model.Model;
import com.kontakt.sdk.android.common.model.ResolvedId;
import com.kontakt.sdk.android.common.model.SecureProfileUid;
import com.kontakt.sdk.android.common.profile.IEddystoneDevice;
import com.kontakt.sdk.android.common.profile.ISecureProfile;
import com.kontakt.sdk.android.common.profile.RemoteBluetoothDevice;
import com.kontakt.sdk.android.common.util.SDKPreconditions;

public class SecureProfile implements ISecureProfile {

  public static final Creator<SecureProfile> CREATOR = new Creator<SecureProfile>() {
    @Override
    public SecureProfile createFromParcel(Parcel source) {
      return new SecureProfile(source);
    }

    @Override
    public SecureProfile[] newArray(int size) {
      return new SecureProfile[size];
    }
  };

  private String macAddress;
  private String name;
  private String uniqueId;
  private String firmwareRevision;
  private Model model;
  private int batteryLevel;
  private int txPower;
  private int rssi;
  private String namespace;
  private String instanceId;
  private boolean shuffled;
  private KontaktTelemetry telemetry;

  SecureProfile(Builder builder) {
    this.macAddress = builder.macAddress;
    this.name = builder.name;
    this.uniqueId = builder.uniqueId;
    this.firmwareRevision = builder.firmwareRevision;
    this.model = builder.model;
    this.batteryLevel = builder.batteryLevel;
    this.txPower = builder.txPower;
    this.namespace = builder.namespace;
    this.instanceId = builder.instanceId;
    this.shuffled = builder.shuffled;
    this.rssi = builder.rssi;
    this.telemetry = builder.telemetry;
  }

  protected SecureProfile(Parcel in) {
    this.macAddress = in.readString();
    this.name = in.readString();
    this.uniqueId = in.readString();
    this.firmwareRevision = in.readString();
    int tmpModel = in.readInt();
    this.model = Model.fromCode(tmpModel);
    this.batteryLevel = in.readInt();
    this.txPower = in.readInt();
    this.rssi = in.readInt();
    this.namespace = in.readString();
    this.instanceId = in.readString();
    this.shuffled = in.readByte() != 0;
    this.telemetry = in.readParcelable(KontaktTelemetry.class.getClassLoader());
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public String getMacAddress() {
    return macAddress;
  }

  @Override
  public String getUniqueId() {
    return uniqueId;
  }

  @Override
  public String getFirmwareRevision() {
    return firmwareRevision;
  }

  public Model getModel() {
    return model;
  }

  @Override
  public int getBatteryLevel() {
    return batteryLevel;
  }

  @Override
  public int getTxPower() {
    return txPower;
  }

  @Override
  public String getNamespace() {
    return namespace;
  }

  public String getInstanceId() {
    return instanceId;
  }

  @Override
  public boolean isShuffled() {
    return shuffled;
  }

  @Override
  public int getRssi() {
    return rssi;
  }

  @Override
  public KontaktTelemetry getTelemetry() {
    return telemetry;
  }

  public void setRssi(int rssi) {
    this.rssi = rssi;
  }

  @Override
  public String toString() {
    return "SecureProfile{" +
        "macAddress='" + macAddress + '\'' +
        ", name='" + name + '\'' +
        ", uniqueId='" + uniqueId + '\'' +
        ", firmwareRevision='" + firmwareRevision + '\'' +
        ", model='" + model + '\'' +
        ", batteryLevel=" + batteryLevel +
        ", txPower=" + txPower +
        ", rssi=" + rssi +
        ", namespace='" + namespace + '\'' +
        ", instanceId='" + instanceId + '\'' +
        ", shuffled=" + shuffled +
        ", telemetry=" + telemetry +
        '}';
  }

  @Override
  public int compareTo(ISecureProfile iSecureProfile) {
    SDKPreconditions.checkNotNull(iSecureProfile, "Comparing to null device!");
    return Integer.valueOf(hashCode()).compareTo(iSecureProfile.hashCode());
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    SecureProfile that = (SecureProfile) o;

    if (batteryLevel != that.batteryLevel) return false;
    if (txPower != that.txPower) return false;
    if (rssi != that.rssi) return false;
    if (shuffled != that.shuffled) return false;
    if (macAddress != null ? !macAddress.equals(that.macAddress) : that.macAddress != null) return false;
    if (name != null ? !name.equals(that.name) : that.name != null) return false;
    if (uniqueId != null ? !uniqueId.equals(that.uniqueId) : that.uniqueId != null) return false;
    if (firmwareRevision != null ? !firmwareRevision.equals(that.firmwareRevision) : that.firmwareRevision != null) return false;
    if (model != that.model) return false;
    if (namespace != null ? !namespace.equals(that.namespace) : that.namespace != null) return false;
    if (instanceId != null ? !instanceId.equals(that.instanceId) : that.instanceId != null) return false;
    return telemetry != null ? telemetry.equals(that.telemetry) : that.telemetry == null;
  }

  @Override
  public int hashCode() {
    int result = macAddress != null ? macAddress.hashCode() : 0;
    result = 31 * result + (name != null ? name.hashCode() : 0);
    result = 31 * result + (uniqueId != null ? uniqueId.hashCode() : 0);
    result = 31 * result + (firmwareRevision != null ? firmwareRevision.hashCode() : 0);
    result = 31 * result + (model != null ? model.hashCode() : 0);
    result = 31 * result + batteryLevel;
    result = 31 * result + txPower;
    result = 31 * result + rssi;
    result = 31 * result + (namespace != null ? namespace.hashCode() : 0);
    result = 31 * result + (instanceId != null ? instanceId.hashCode() : 0);
    result = 31 * result + (shuffled ? 1 : 0);
    result = 31 * result + (telemetry != null ? telemetry.hashCode() : 0);
    return result;
  }

  @Override
  public int describeContents() {
    return 0;
  }

  @Override
  public void writeToParcel(Parcel dest, int flags) {
    dest.writeString(this.macAddress);
    dest.writeString(this.name);
    dest.writeString(this.uniqueId);
    dest.writeString(this.firmwareRevision);
    dest.writeInt(this.model == null ? -1 : this.model.getCode());
    dest.writeInt(this.batteryLevel);
    dest.writeInt(this.txPower);
    dest.writeInt(this.rssi);
    dest.writeString(this.namespace);
    dest.writeString(this.instanceId);
    dest.writeByte(this.shuffled ? (byte) 1 : (byte) 0);
    dest.writeParcelable(this.telemetry, flags);
  }

  public static class Builder {

    String macAddress;
    String name;
    String uniqueId;
    String firmwareRevision;
    Model model;
    int batteryLevel;
    int txPower;
    String namespace;
    String instanceId;
    boolean shuffled;
    int rssi;
    KontaktTelemetry telemetry;

    public Builder() {
    }

    public Builder(ISecureProfile secureDevice) {
      this.macAddress = secureDevice.getMacAddress();
      this.name = secureDevice.getName();
      this.uniqueId = secureDevice.getUniqueId();
      this.firmwareRevision = secureDevice.getFirmwareRevision();
      this.model = secureDevice.getModel();
      this.batteryLevel = secureDevice.getBatteryLevel();
      this.txPower = secureDevice.getTxPower();
      this.namespace = secureDevice.getNamespace();
      this.instanceId = secureDevice.getInstanceId();
      this.rssi = secureDevice.getRssi();
      this.shuffled = secureDevice.isShuffled();

      final KontaktTelemetry telemetry = secureDevice.getTelemetry();
      if (telemetry != null) {
        this.telemetry = new KontaktTelemetry.Builder()
            .timestamp(telemetry.getTimestamp())
            .batteryLevel(telemetry.getBatteryLevel())
            .uptime(telemetry.getUptime())
            .systemLoad(telemetry.getSystemLoad())
            .error(telemetry.getError())
            .sensitivity(telemetry.getSensitivity())
            .acceleration(telemetry.getAcceleration())
            .lastDoubleTap(telemetry.getLastDoubleTap())
            .lastThreshold(telemetry.getLastThreshold())
            .lightSensor(telemetry.getLightSensor())
            .temperature(telemetry.getTemperature())
            .bleScans(telemetry.getBleScans())
            .wifiScans(telemetry.getWifiScans())
            .bleDevices(telemetry.getBleDevices())
            .build();
      }
    }

    public Builder(RemoteBluetoothDevice remoteBluetoothDevice) {
      this.macAddress = remoteBluetoothDevice.getAddress();
      this.name = remoteBluetoothDevice.getName();
      this.uniqueId = remoteBluetoothDevice.getUniqueId();
      this.firmwareRevision = remoteBluetoothDevice.getFirmwareVersion();
      this.model = Model.UNKNOWN;
      this.batteryLevel = remoteBluetoothDevice.getBatteryPower();
      this.txPower = remoteBluetoothDevice.getTxPower();
      this.rssi = remoteBluetoothDevice.getRssi();
      this.shuffled = remoteBluetoothDevice.isShuffled();
      if (remoteBluetoothDevice instanceof IEddystoneDevice) {
        this.namespace = ((IEddystoneDevice) remoteBluetoothDevice).getNamespace();
        this.instanceId = ((IEddystoneDevice) remoteBluetoothDevice).getInstanceId();
      }
    }

    public Builder macAddress(String macAddress) {
      this.macAddress = macAddress;
      return this;
    }

    public Builder name(String name) {
      this.name = name;
      return this;
    }

    public Builder uniqueId(String uniqueId) {
      this.uniqueId = uniqueId;
      return this;
    }

    public Builder firmwareRevision(String firmwareRevision) {
      this.firmwareRevision = firmwareRevision;
      return this;
    }

    public Builder model(Model model) {
      this.model = model;
      return this;
    }

    public Builder batteryLevel(int batteryLevel) {
      this.batteryLevel = batteryLevel;
      return this;
    }

    public Builder txPower(int txPower) {
      this.txPower = txPower;
      return this;
    }

    public Builder namespace(String namespace) {
      this.namespace = namespace;
      return this;
    }

    public Builder instanceId(String instanceId) {
      this.instanceId = instanceId;
      return this;
    }

    public Builder shuffled(boolean isShuffled) {
      this.shuffled = isShuffled;
      return this;
    }

    public Builder rssi(int rssi) {
      this.rssi = rssi;
      return this;
    }

    public Builder telemetry(KontaktTelemetry telemetry) {
      this.telemetry = telemetry;
      return this;
    }

    /**
     * This property is used internally by Kontakt.io SDK. It can be safely ignored.
     *
     * @param resolvedId resolved Id.
     * @return Builder instance.
     */
    public Builder resolvedId(ResolvedId resolvedId) {
      SecureProfileUid secureProfileUid = resolvedId.getSecureProfileUID();
      this.namespace = secureProfileUid.getNamespace();
      this.instanceId = secureProfileUid.getInstanceId();
      this.uniqueId = resolvedId.getUniqueId();
      return this;
    }

    public SecureProfile build() {
      return new SecureProfile(this);
    }
  }
}

==> sdk-4.0.3-sources.jar: com/kontakt/sdk/android/ble/device/SecureProfile.java <==
package com.kontakt.sdk.android.ble.device;

import android.os.Parcel;
import com.kontakt.sdk.android.ble.spec.KontaktTelemetry;
import com.kontakt.sdk.android.common.model.Model;
import com.kontakt.sdk.android.common.model.ResolvedId;
import com.kontakt.sdk.android.common.model.SecureProfileUid;
import com.kontakt.sdk.android.common.profile.IEddystoneDevice;
import com.kontakt.sdk.android.common.profile.ISecureProfile;
import com.kontakt.sdk.android.common.profile.RemoteBluetoothDevice;
import com.kontakt.sdk.android.common.util.SDKPreconditions;

public class SecureProfile implements ISecureProfile {

  public static final Creator<SecureProfile> CREATOR = new Creator<SecureProfile>() {
    @Override
    public SecureProfile createFromParcel(Parcel source) {
      return new SecureProfile(source);
    }

    @Override
    public SecureProfile[] newArray(int size) {
      return new SecureProfile[size];
    }
  };

  private String macAddress;
  private String name;
  private String uniqueId;
  private String firmwareRevision;
  private Model model;
  private int batteryLevel;
  private int txPower;
  private int rssi;
  private String namespace;
  private String instanceId;
  private boolean shuffled;
  private KontaktTelemetry telemetry;

  SecureProfile(Builder builder) {
    this.macAddress = builder.macAddress;
    this.name = builder.name;
    this.uniqueId = builder.uniqueId;
    this.firmwareRevision = builder.firmwareRevision;
    this.model = builder.model;
    this.batteryLevel = builder.batteryLevel;
    this.txPower = builder.txPower;
    this.namespace = builder.namespace;
    this.instanceId = builder.instanceId;
    this.shuffled = builder.shuffled;
    this.rssi = builder.rssi;
    this.telemetry = builder.telemetry;
  }

  protected SecureProfile(Parcel in) {
    this.macAddress = in.readString();
    this.name = in.readString();
    this.uniqueId = in.readString();
    this.firmwareRevision = in.readString();
    int tmpModel = in.readInt();
    this.model = Model.fromCode(tmpModel);
    this.batteryLevel = in.readInt();
    this.txPower = in.readInt();
    this.rssi = in.readInt();
    this.namespace = in.readString();
    this.instanceId = in.readString();
    this.shuffled = in.readByte() != 0;
    this.telemetry = in.readParcelable(KontaktTelemetry.class.getClassLoader());
  }

  public SecureProfile updateWith(final SecureProfile profile) {
    if (profile == null) {
      return this;
    }

    if (profile.name != null) {
      this.name = profile.name;
    }
    if (profile.uniqueId != null) {
      this.uniqueId = profile.uniqueId;
    }
    if (profile.firmwareRevision != null) {
      this.firmwareRevision = profile.firmwareRevision;
    }
    if (profile.model != null) {
      this.model = profile.model;
    }
    if (profile.batteryLevel != 0) {
      this.batteryLevel = profile.batteryLevel;
    }
    if (profile.txPower != 0) {
      this.txPower = profile.txPower;
    }
    if (profile.namespace != null) {
      this.namespace = profile.namespace;
    }
    if (profile.instanceId != null) {
      this.instanceId = profile.instanceId;
    }
    if (profile.telemetry != null) {
      this.telemetry = profile.telemetry;
    } else {
      // If telemetry is null, we can override shuffled property.
      // Otherwise we can't because telemetry is parsed separately
      // and appended to the rest of secure profile so shuffled
      // property is always set to false which could not be true at all.
      this.shuffled = profile.shuffled;
    }

    return this;
  }

  @Override
  public String getName() {
    return name;
  }

  @Override
  public String getMacAddress() {
    return macAddress;
  }

  @Override
  public String getUniqueId() {
    return uniqueId;
  }

  @Override
  public String getFirmwareRevision() {
    return firmwareRevision;
  }

  public Model getModel() {
    return model;
  }

  @Override
  public int getBatteryLevel() {
    return batteryLevel;
  }

  @Override
  public int getTxPower() {
    return txPower;
  }

  @Override
  public String getNamespace() {
    return namespace;
  }

  public String getInstanceId() {
    return instanceId;
  }

  @Override
  public boolean isShuffled() {
    return shuffled;
  }

  @Override
  public int getRssi() {
    return rssi;
  }

  @Override
  public KontaktTelemetry getTelemetry() {
    return telemetry;
  }

  public void setRssi(int rssi) {
    this.rssi = rssi;
  }

  @Override
  public String toString() {
    return "SecureProfile{" +
        "macAddress='" + macAddress + '\'' +
        ", name='" + name + '\'' +
        ", uniqueId='" + uniqueId + '\'' +
        ", firmwareRevision='" + firmwareRevision + '\'' +
        ", model='" + model + '\'' +
        ", batteryLevel=" + batteryLevel +
        ", txPower=" + txPower +
        ", rssi=" + rssi +
        ", namespace='" + namespace + '\'' +
        ", instanceId='" + instanceId + '\'' +
        ", shuffled=" + shuffled +
        ", telemetry=" + telemetry +
        '}';
  }

  @Override
  public int compareTo(ISecureProfile iSecureProfile) {
    SDKPreconditions.checkNotNull(iSecureProfile, "Comparing to null device!");
    return Integer.valueOf(hashCode()).compareTo(iSecureProfile.hashCode());
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    SecureProfile that = (SecureProfile) o;

    if (batteryLevel != that.batteryLevel) return false;
    if (txPower != that.txPower) return false;
    if (rssi != that.rssi) return false;
    if (shuffled != that.shuffled) return false;
    if (macAddress != null ? !macAddress.equals(that.macAddress) : that.macAddress != null) return false;
    if (name != null ? !name.equals(that.name) : that.name != null) return false;
    if (uniqueId != null ? !uniqueId.equals(that.uniqueId) : that.uniqueId != null) return false;
    if (firmwareRevision != null ? !firmwareRevision.equals(that.firmwareRevision) : that.firmwareRevision != null) return false;
    if (model != that.model) return false;
    if (namespace != null ? !namespace.equals(that.namespace) : that.namespace != null) return false;
    if (instanceId != null ? !instanceId.equals(that.instanceId) : that.instanceId != null) return false;
    return telemetry != null ? telemetry.equals(that.telemetry) : that.telemetry == null;
  }

  @Override
  public int hashCode() {
    int result = macAddress != null ? macAddress.hashCode() : 0;
    result = 31 * result + (name != null ? name.hashCode() : 0);
    result = 31 * result + (uniqueId != null ? uniqueId.hashCode() : 0);
    result = 31 * result + (firmwareRevision != null ? firmwareRevision.hashCode() : 0);
    result = 31 * result + (model != null ? model.hashCode() : 0);
    result = 31 * result + batteryLevel;
    result = 31 * result + txPower;
    result = 31 * result + rssi;
    result = 31 * result + (namespace != null ? namespace.hashCode() : 0);
    result = 31 * result + (instanceId != null ? instanceId.hashCode() : 0);
    result = 31 * result + (shuffled ? 1 : 0);
    result = 31 * result + (telemetry != null ? telemetry.hashCode() : 0);
    return result;
  }

  @Override
  public int describeContents() {
    return 0;
  }

  @Override
  public void writeToParcel(Parcel dest, int flags) {
    dest.writeString(this.macAddress);
    dest.writeString(this.name);
    dest.writeString(this.uniqueId);
    dest.writeString(this.firmwareRevision);
    dest.writeInt(this.model == null ? -1 : this.model.getCode());
    dest.writeInt(this.batteryLevel);
    dest.writeInt(this.txPower);
    dest.writeInt(this.rssi);
    dest.writeString(this.namespace);
    dest.writeString(this.instanceId);
    dest.writeByte(this.shuffled ? (byte) 1 : (byte) 0);
    dest.writeParcelable(this.telemetry, flags);
  }

  public static class Builder {

    String macAddress;
    String name;
    String uniqueId;
    String firmwareRevision;
    Model model;
    int batteryLevel;
    int txPower;
    String namespace;
    String instanceId;
    boolean shuffled;
    int rssi;
    KontaktTelemetry telemetry;

    public Builder() {
    }

    public Builder(ISecureProfile secureDevice) {
      this.macAddress = secureDevice.getMacAddress();
      this.name = secureDevice.getName();
      this.uniqueId = secureDevice.getUniqueId();
      this.firmwareRevision = secureDevice.getFirmwareRevision();
      this.model = secureDevice.getModel();
      this.batteryLevel = secureDevice.getBatteryLevel();
      this.txPower = secureDevice.getTxPower();
      this.namespace = secureDevice.getNamespace();
      this.instanceId = secureDevice.getInstanceId();
      this.rssi = secureDevice.getRssi();
      this.shuffled = secureDevice.isShuffled();

      final KontaktTelemetry telemetry = secureDevice.getTelemetry();
      if (telemetry != null) {
        this.telemetry = new KontaktTelemetry.Builder()
            .timestamp(telemetry.getTimestamp())
            .batteryLevel(telemetry.getBatteryLevel())
            .uptime(telemetry.getUptime())
            .systemLoad(telemetry.getSystemLoad())
            .error(telemetry.getError())
            .sensitivity(telemetry.getSensitivity())
            .acceleration(telemetry.getAcceleration())
            .lastDoubleTap(telemetry.getLastDoubleTap())
            .lastThreshold(telemetry.getLastThreshold())
            .lightSensor(telemetry.getLightSensor())
            .temperature(telemetry.getTemperature())
            .bleScans(telemetry.getBleScans())
            .wifiScans(telemetry.getWifiScans())
            .bleDevices(telemetry.getBleDevices())
            .build();
      }
    }

    public Builder(RemoteBluetoothDevice remoteBluetoothDevice) {
      this.macAddress = remoteBluetoothDevice.getAddress();
      this.name = remoteBluetoothDevice.getName();
      this.uniqueId = remoteBluetoothDevice.getUniqueId();
      this.firmwareRevision = remoteBluetoothDevice.getFirmwareVersion();
      this.model = Model.UNKNOWN;
      this.batteryLevel = remoteBluetoothDevice.getBatteryPower();
      this.txPower = remoteBluetoothDevice.getTxPower();
      this.rssi = remoteBluetoothDevice.getRssi();
      this.shuffled = remoteBluetoothDevice.isShuffled();
      if (remoteBluetoothDevice instanceof IEddystoneDevice) {
        this.namespace = ((IEddystoneDevice) remoteBluetoothDevice).getNamespace();
        this.instanceId = ((IEddystoneDevice) remoteBluetoothDevice).getInstanceId();
      }
    }

    public Builder macAddress(String macAddress) {
      this.macAddress = macAddress;
      return this;
    }

    public Builder name(String name) {
      this.name = name;
      return this;
    }

    public Builder uniqueId(String uniqueId) {
      this.uniqueId = uniqueId;
      return this;
    }

    public Builder firmwareRevision(String firmwareRevision) {
      this.firmwareRevision = firmwareRevision;
      return this;
    }

    public Builder model(Model model) {
      this.model = model;
      return this;
    }

    public Builder batteryLevel(int batteryLevel) {
      this.batteryLevel = batteryLevel;
      return this;
    }

    public Builder txPower(int txPower) {
      this.txPower = txPower;
      return this;
    }

    public Builder namespace(String namespace) {
      this.namespace = namespace;
      return this;
    }

    public Builder instanceId(String instanceId) {
      this.instanceId = instanceId;
      return this;
    }

    public Builder shuffled(boolean isShuffled) {
      this.shuffled = isShuffled;
      return this;
    }

    public Builder rssi(int rssi) {
      this.rssi = rssi;
      return this;
    }

    public Builder telemetry(KontaktTelemetry telemetry) {
      this.telemetry = telemetry;
      return this;
    }

    /**
     * This property is used internally by Kontakt.io SDK. It can be safely ignored.
     *
     * @param resolvedId resolved Id.
     * @return Builder instance.
     */
    public Builder resolvedId(ResolvedId resolvedId) {
      SecureProfileUid secureProfileUid = resolvedId.getSecureProfileUID();
      this.namespace = secureProfileUid.getNamespace();
      this.instanceId = secureProfileUid.getInstanceId();
      this.uniqueId = resolvedId.getUniqueId();
      return this;
    }

    public SecureProfile build() {
      return new SecureProfile(this);
    }
  }
}
